import { system, world } from "@minecraft/server";

system.runInterval(() => {
  const Players = [...world.getPlayers()];
  if (Players.length === 0) return;

  Players.forEach(player => {
    let health = player.getComponent("health");
    let pHealth = Math.ceil(health.currentValue);
    let pMaxHealth = Math.ceil(health.effectiveMax);

    let pHealthPercentage = (pHealth / pMaxHealth) * 100;

    let healthColor = getHealthColor(pHealthPercentage);
    let healthBar = getHealthBar(pHealthPercentage);

    player.nameTag = player.name + "\nHP:" + healthColor + pHealth + healthBar;

  });
} , 1)

function getHealthColor(percentage){
  let healthColor = "§c";
  if(percentage >= 80) { healthColor = "§2" } //green
  else if(percentage >= 60) { healthColor = "§e" } //yellow
  else if(percentage >= 40) { healthColor = "§6" } //orange
  else if(percentage >= 20) { healthColor = "§m" }; //red

  return healthColor;
}

function getHealthBar(percentage){
  let healthBar = " ";
  let n = Math.floor(percentage / 10); 
  for (let i = 0; i < n; i++) {
    healthBar = healthBar + "❚";
  }
  if (decimalPart(percentage / 10, 1) > 0) {
    healthBar = healthBar + "●";
  }
  return healthBar;
}

function decimalPart(num, decDigits){
  var decPart = num - ((num >= 0) ? Math.floor(num) : Math.ceil(num));
  return decPart.toFixed(decDigits);
}